@@ -299,6 +299,12 @@ def test_custom_random_greedy():
     assert path_info.largest_intermediate == optimizer.best['size']
     assert path_info.opt_cost == optimizer.best['flops']
 
+    # check error if we try and reuse the optimizer on a different expression
+    eq, shapes = oe.helpers.rand_equation(10, 4, seed=41)
+    views = list(map(np.ones, shapes))
+    with pytest.raises(ValueError):
+        path, path_info = oe.contract_path(eq, *views, optimize=optimizer)
+
 
 def test_custom_branchbound():
     eq, shapes = oe.helpers.rand_equation(8, 4, seed=42)
@@ -320,6 +326,12 @@ def test_custom_branchbound():
     assert path_info.largest_intermediate == optimizer.best['size']
     assert path_info.opt_cost == optimizer.best['flops']
 
+    # check error if we try and reuse the optimizer on a different expression
+    eq, shapes = oe.helpers.rand_equation(8, 4, seed=41)
+    views = list(map(np.ones, shapes))
+    with pytest.raises(ValueError):
+        path, path_info = oe.contract_path(eq, *views, optimize=optimizer)
+
 
 @pytest.mark.skipif(sys.version_info < (3, 2), reason="requires python3.2 or higher")
 def test_parallel_random_greedy():
